pub struct AppId(/* private fields */);Expand description
An application identifier that defines the namespace two nodes must share in order to see each other as peers.
Valid AppIds match ^[a-z][a-z0-9-]{1,31}$:
- first character: lowercase ASCII letter
- remaining: lowercase ASCII letters, digits, or
- - length: 2–32 characters
Implementations