pub struct ProxyAddParams {
pub id: String,
pub name: String,
pub listen_port: u16,
pub target_host: String,
pub target_port: u16,
pub target_scheme: String,
}Expand description
Parameters for starting a reverse proxy via the network provider.
Fields
id: StringUnique identifier for this proxy.
name: StringHuman-readable name.
listen_port: u16Port on which the proxy listens on the tailnet (TLS).
target_host: StringTarget host to forward to (e.g., “localhost”).
target_port: u16Target port to forward to.
target_scheme: StringTarget scheme (“http” or “https”).